@@ -92,7 +92,7 @@ def get_message_body():
 
 ## initialize testing for specific Agent given user and psw or using the token, needed to pass the agent_slug too
 ## this function inizialite the counters and the html message for a specific agent. It also login on that  agent
-def initialize_agent_test(username = '', password = '', token = None, agent_slug = ''):
+def initialize_agent_test(username = '', password = '', domain = 'askdata', token = None, agent_slug = ''):
     
     global message_body, agent_id, test_passed, test_failed, glob_token
     
@@ -107,9 +107,9 @@ def initialize_agent_test(username = '', password = '', token = None, agent_slug
         glob_token = token
         
     else:
-        askdata = Askdata(username = username, password = password, env = 'prod')
+        askdata = Askdata(username = username, password = password, domainlogin = domain, env = 'prod')
             
-        glob_token = test_login(username, password, "askdata").json()["access_token"]
+        glob_token = test_login(username = username, password = password,  domain = domain, env = 'prod').json()["access_token"]
 
     agent = askdata.agent(agent_slug)
 
